@@ -13,4 +13,7 @@ from django_declarative_apis.adapters import resource_adapter
 
 UUID4_REGEX = r"[0-9a-fA-F]{8}-([0-9a-fA-F]{4}-){3}[0-9a-fA-F]{12}"
 
-urlpatterns = [url(r"^simple", resource_adapter(get=views.SimpleEndpointDefinition))]
+urlpatterns = [
+    url(r"^simple", resource_adapter(get=views.SimpleEndpointDefinition)),
+    url(r"^dict", resource_adapter(get=views.DictEndpointDefinition)),
+]
